pub enum PathfindMode {
Refined,
Coarse,
AStar,
Waypoints,
ThetaStar,
}Expand description
Determines which algorithm to use for pathfinding.
Variants
Refined
Hierarchical pathfinding with the final path refined with line tracing.
Coarse
Hierarchical pathfinding using only cached paths. Use this if you’re not concerned with trying to find the shortest path.
AStar
Full-grid A* pathfinding without hierarchy. Useful for small grids or a turn based pathfinding path where movement cost needs to be the most accurate and cpu usage isn’t a concern.
Waypoints
Any-Angle HPA* pathfinding, returns only the key points where line of sight breaks to the goal.
ThetaStar
Any-Angle θ* pathfinding without hierarchy. Note that Theta* only returns the key points where line of sight breaks to the goal. It provides a very direct path but calculation is slow. This is only recommended for games with freeform movement.