pub struct PathingSet;Expand description
The PathingSet is a system set that is used to group the pathfinding systems together.
You can use this set to schedule systems before or after the pathfinding systems.